@@ -193,6 +193,8 @@ command=function() Met.Selection(datos,externa))
     command=function() Met.Norm(datos))
   tkadd(Pretratamiento,"command",label="Baseline",
     command=function() Met.Baseline(datos))
+  tkadd(Pretratamiento,"command",label="Baseline (FTICRMS)",
+    command=function() Baseline.Correction())
   tkadd(Pretratamiento,"command",label="Metabolites order by discriminantion quality",
     command=function() Met.Order(datos))
   tkadd(Pretratamiento,"command",label="Metabolites Selection",
